DataStore class final

Plugin data store

Constructors

DataStore({required PickerStyle style, required CameraStyle cameraStyle, required PickerController pickerController, required VoidCallback onCameraPermissionDeniedCallback, required bool enableAudio})
Data store

Properties

advancedPickerCompleter → Completer<({List<XFile> assets, bool needMirrorPhoto})>
Main completer for advancedPicker
final
allowedTypes ↔ List<String>
getter/setter pair
availablePath ↔ ValueNotifier<List<AssetPathEntity>>
getter/setter pair
cameraController ↔ CameraController
getter/setter pair
cameraStyle → CameraStyle
Camera style
final
enableAudio → bool
Enable audio - if true will request permission to microphone
final
hashCode → int
The hash code for this object.
no setterinherited
hasMoreToLoad ↔ Map<String, bool>
getter/setter pair
isNeedToShowAlert ↔ bool
getter/setter pair
isNeedToShowCamera ↔ bool
getter/setter pair
isNeedToShowFolders ↔ bool
getter/setter pair
isNeedToTakeVideo ↔ bool
getter/setter pair
isNeedToToggleDirectories ↔ bool
getter/setter pair
isPreviewCameraReady ↔ ValueNotifier<bool>
getter/setter pair
isPreviewOpen ↔ ValueNotifier<bool>
getter/setter pair
limitToSelection ↔ int
getter/setter pair
mainAssetsCompleter → Completer<List<AssetModel>>
Main completer for assets picker
final
mainCompleter → Completer<List<XFile>>
Main completer
final
maxVideoDuration ↔ int
getter/setter pair
onCameraPermissionDeniedCallback → VoidCallback
Open permission settings
final
pages ↔ Map<String, int>
getter/setter pair
pathData ↔ Map<String, ValueNotifier<List<AssetEntity>>>
getter/setter pair
pickerController → PickerController
Picker controller
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedAssets ↔ ValueNotifier<List<AssetModel>>
getter/setter pair
selectedPath ↔ ValueNotifier<AssetPathEntity?>
getter/setter pair
sizePerPage → int
final
streamController → StreamController<List<XFile>>
Stream controller for the data store
final
style → PickerStyle
Picker style
final
totalEntitiesCount ↔ Map<String, int>
getter/setter pair

Methods

dispose() → Future<void>
initCameras() → Future<void>
Initialize camera
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited