AssetModel class

Asset model

Constructors

AssetModel({required String id, required XFile file, required AssetType type})
Asset model
AssetModel.fromXFile(XFile file)
Create asset model from xfile
factory

Properties

file → XFile
Asset file
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Asset id
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AssetType
Asset type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAssetEntities(List<AssetEntity> entities) → Future<List<AssetModel>>
Create asset model list from asset entity list
fromAssetEntity(AssetEntity entity) → Future<AssetModel>
Create asset model from asset entity