CameraStyle class

Camera style

Constructors

CameraStyle({Widget cameraCloseIcon = const Icon(Icons.close, color: Colors.white), Widget takePictureIcon = const Icon(Icons.camera, color: Colors.white), Widget chooseCameraIcon = const Icon(Icons.camera_alt, color: Colors.white), Widget cameraBackButton = const Icon(Icons.arrow_back_ios_new, color: Colors.white), Widget cameraAddMediaButton = const Icon(Icons.add, color: Colors.white), Widget cameraDeleteMediaButton = const Icon(Icons.delete, color: Colors.white), Widget cameraSelectedMediaButton = const Icon(Icons.done, color: Colors.white), Widget videoIcon = const Icon(Icons.video_call_rounded, color: Colors.white), Widget flipCameraIcon = const Icon(Icons.flip_camera_ios, color: Colors.white), String finishButtonTitle = 'Done', TextStyle finishButtonStyle = const TextStyle(color: Colors.white, fontSize: 16.0, fontWeight: FontWeight.w700), EdgeInsets finishButtonPadding = const EdgeInsets.only(bottom: 8.0), double basicCameraViewBorderRadius = 34, double basicCameraCropContainerHeight = 392, double basicCameraCropContainerBorderRadius = 24, Color basicCameraCropContainerBorderColor = Colors.white, Widget basicCameraFlashIcon = const Icon(Icons.flash_on, color: Colors.white), Widget basicCameraFlashAutoIcon = const Icon(Icons.flash_auto, color: Colors.white), Widget basicCameraFlashOffIcon = const Icon(Icons.flash_off, color: Colors.white), Widget? basicCameraTakePhotoButton, bool showBasicCamera = false})
Camera style

Properties

basicCameraCropContainerBorderColor → Color
Basic camera crop container border color
final
basicCameraCropContainerBorderRadius → double
Basic camera crop container border radius
final
basicCameraCropContainerHeight → double
Basic camera crop container height
final
basicCameraFlashAutoIcon → Widget
Basic camera flash auto icon
final
basicCameraFlashIcon → Widget
Basic camera flash icon
final
basicCameraFlashOffIcon → Widget
Basic camera flash off icon
final
basicCameraTakePhotoButton → Widget?
Basic camera takePhoto button
final
basicCameraViewBorderRadius → double
Basic camera view border radius
final
cameraAddMediaButton → Widget
Camera add media button
final
cameraBackButton → Widget
Camera back button
final
cameraCloseIcon → Widget
Camera close icon
final
cameraDeleteMediaButton → Widget
Camera delete media button
final
cameraSelectedMediaButton → Widget
Camera selected media button
final
chooseCameraIcon → Widget
Choose camera icon
final
finishButtonPadding → EdgeInsets
Finish button padding
final
finishButtonStyle → TextStyle
Finish button style
final
finishButtonTitle → String
Finish button title
final
flipCameraIcon → Widget
Flip camera icon
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBasicCamera → bool
Basic camera camera style
final
takePictureIcon → Widget
Take picture icon
final
videoIcon → Widget
Video icon
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited