CloseAlertStyle class

Close alert style

Constructors

CloseAlertStyle({required String title, required String message, required String positiveButtonText, required String negativeButtonText, TextStyle titleTextStyle = const TextStyle(fontSize: 18, fontWeight: FontWeight.bold), TextStyle messageTextStyle = const TextStyle(fontSize: 16), TextStyle positiveButtonTextStyle = const TextStyle(fontSize: 16, color: Colors.blue), TextStyle negativeButtonTextStyle = const TextStyle(fontSize: 16, color: Colors.red), BoxDecoration containerDecoration = const BoxDecoration(color: Colors.white, borderRadius: BorderRadius.all(Radius.circular(10)))})
Close alert style

Properties

containerDecoration → BoxDecoration
Container decoration
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
Message
final
messageTextStyle → TextStyle
Message text style
final
negativeButtonText → String
Negative button text
final
negativeButtonTextStyle → TextStyle
Negative button text style
final
positiveButtonText → String
Positive button text
final
positiveButtonTextStyle → TextStyle
Positive button text style
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
Title
final
titleTextStyle → TextStyle
Title text style
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited