PickerController class

Picker controller

Inheritance

Constructors

PickerController({double initialChildSize = 0.5, double minChildSize = 0, double maxChildSize = 0.9, List<double> snap = const <double>[]})
Constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
initialChildSize → double
Initial child size
final
isAttached → bool
Returns Whether any DraggableScrollableController objects have attached themselves to the DraggableScrollableSheet.
no setterinherited
maxChildSize → double
Maximum child size
final
minChildSize → double
Minimum child size
final
pixels → double
Get the current pixel height of the attached sheet.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sheet → GlobalKey<State<StatefulWidget>>
Key of the sheet
final
size → double
Get the current size (as a fraction of the parent height) of the attached sheet.
no setterinherited
snap → List<double>
Snap
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
animateSheet(double size) → Future<void>
Animate sheet to a specific size
animateTo(double size, {required Duration duration, required Curve curve}) → Future<void>
Animates the attached sheet from its current size to the given size, a fractional value of the parent container's height.
inherited
closeAssetsPicker() → Future<void>
Close the assets picker
closePicker() → Future<void>
Close the picker
dispose() → void
Discards any resources used by the object.
inherited
hide() → Future<void>
Hide the sheet
jumpTo(double size) → void
Jumps the attached sheet from its current size to the given size, a fractional value of the parent container's height.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pixelsToSize(double pixels) → double
Convert a sheet's pixel height to size (fractional value of parent container height).
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
Reset the attached sheet to its initial size (see: DraggableScrollableSheet.initialChildSize).
inherited
sizeToPixels(double size) → double
Convert a sheet's size (fractional value of parent container height) to pixels.
inherited
toString() → String
A string representation of this object.
inherited
tryToHide() → Future<void>
Try to hide the sheet if there are selected assets

Operators

operator ==(Object other) → bool
The equality operator.
inherited