PickerStyle class

Picker style

Constructors

PickerStyle({BorderRadius borderRadius = const BorderRadius.all(Radius.circular(10)), Color backgroundColor = Colors.white, Color textColor = Colors.black, Color selectIconBackgroundColor = Colors.white, Widget selectIcon = const Icon(Icons.check, color: Colors.black), bool isNeedDragIndicator = true, Border selectIconBorder = const Border(), Color dragIndicatorColor = Colors.grey, EdgeInsets mainPadding = const EdgeInsets.all(10), BorderRadius itemsBorderRadius = const BorderRadius.all(Radius.circular(10)), Color shimmerBaseColor = Colors.grey, Color shimmerHighlightColor = Colors.white, Alignment selectIconAlignment = Alignment.topRight, Color dividerColor = Colors.grey, Color selectedFolderTextColor = Colors.white, Color unselectedFolderTextColor = Colors.black, BoxDecoration selectedFolderDecoration = const BoxDecoration(color: Colors.blue, borderRadius: BorderRadius.all(Radius.circular(10))), BoxDecoration unselectedFolderDecoration = const BoxDecoration(color: Colors.grey, borderRadius: BorderRadius.all(Radius.circular(10))), BoxDecoration cameraContainerDecoration = const BoxDecoration(color: Colors.white, borderRadius: BorderRadius.all(Radius.circular(10))), Widget cameraIcon = const Icon(Icons.camera_alt, color: Colors.white), Widget? completeWidget, CloseAlertStyle? closeAlertStyle, Future<bool> showCustomAlert()?, Widget? typeSelectionWidget, double bottomPadding = 0, Widget folderDivider = const Divider(), Widget titleWidget = const Text('Select media'), Widget cameraAndGalleryUnavailableContent = const Text('There is no permission to access the camera and gallery'), Widget cameraUnavailableContent = const Text('There is no permission to access the camera'), Widget galleryUnavailableContent = const Text('There is no permission to access the gallery'), bool hasPermissionToCamera = true, bool hasPermissionToGallery = true, EdgeInsets cameraPreviewPadding = const EdgeInsets.all(16), int crossAxisCount = 4, double crossAxisSpacing = 4, double mainAxisSpacing = 4, Widget? unselectAssetIcon, Widget? customSelectAssetIcon, TextStyle? customSelectAssetCountStyle})
Picker style

Properties

backgroundColor → Color
Background color
final
borderRadius → BorderRadius
Sheet Border radius
final
bottomPadding → double
Bottom padding
final
cameraAndGalleryUnavailableContent → Widget
Camera gallery unavailable content
final
cameraContainerDecoration → BoxDecoration
Camera container decoration
final
cameraIcon → Widget
Camera icon
final
cameraPreviewPadding → EdgeInsets
Camera preview padding
final
cameraUnavailableContent → Widget
Camera unavailable content
final
closeAlertStyle → CloseAlertStyle
Close alert style
no setter
completeWidget → Widget?
Complete widget for the picker (shown at the bottom of the picker when the user has selected media)
final
crossAxisCount → int
The number of children in the cross axis in assets grid
final
crossAxisSpacing → double
The number of logical pixels between each child along the cross axis in assets grid
final
customSelectAssetCountStyle → TextStyle?
Custom selected assets count style
final
customSelectAssetIcon → Widget?
Custom selected asset mark icon
final
dividerColor → Color
Divider color
final
dragIndicatorColor → Color
Drag indicator color
final
folderDivider → Widget
Folder divider
final
galleryUnavailableContent → Widget
Gallery unavailable content
final
hashCode → int
The hash code for this object.
no setterinherited
hasPermissionToCamera → bool
Permission status for camera
final
hasPermissionToGallery → bool
Permission status for gallery
final
isNeedDragIndicator → bool
Is need drag indicator
final
itemsBorderRadius → BorderRadius
Items border radius
final
mainAxisSpacing → double
The number of logical pixels between each child along the main axis in assets grid
final
mainPadding → EdgeInsets
Main padding
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedFolderDecoration → BoxDecoration
Selected folder decoration
final
selectedFolderTextColor → Color
Selected folder text color
final
selectIcon → Widget
Select icon
final
selectIconAlignment → Alignment
Select icon alignment
final
selectIconBackgroundColor → Color
Select icon background color
final
selectIconBorder → Border
Select icon border
final
shimmerBaseColor → Color
Shimmer base color
final
shimmerHighlightColor → Color
Shimmer highlight color
final
showCustomAlert → Future<bool> Function()?
A function that returns a boolean value from your custom alert dialog.
final
textColor → Color
Text color
final
titleWidget → Widget
Picker title widget
final
typeSelectionWidget → Widget?
Type selection widget for the picker (shown at the bottom of the picker when the user dont selected media)
final
unselectAssetIcon → Widget?
Unselected asset mark icon
final
unselectedFolderDecoration → BoxDecoration
Unselected folder decoration
final
unselectedFolderTextColor → Color
Unselected folder text color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited